from setuptools import setup

setup(
    name='lyylog',
    version='1.0.0',
    author='lyy',
    author_email='',
    description='lyylog for lyy',
    packages=packages=find_packages(),
    install_requires=[
        'logging',

    ],
)